@@ -143,7 +143,7 @@ SignalWaiter(ThreadPool *tpoolPtr);
 
 static int
 TpoolEval(Tcl_Interp *interp, char *script, size_t scriptLen,
-                            TpoolResult *rPtr);
+			    TpoolResult *rPtr);
 static void
 SetResult(Tcl_Interp *interp, TpoolResult *rPtr);
 
@@ -213,7 +213,7 @@ TpoolCreateObjCmd(
      */
 
     if (((objc-1) % 2)) {
-        goto usage;
+	goto usage;
     }
 
     minw = TPOOL_MINWORKERS;
@@ -225,28 +225,28 @@ TpoolCreateObjCmd(
      */
 
     for (ii = 1; ii < objc; ii += 2) {
-        char *opt = Tcl_GetString(objv[ii]);
-        if (OPT_CMP(opt, "-minworkers")) {
-            if (Tcl_GetIntFromObj(interp, objv[ii+1], &minw) != TCL_OK) {
-                return TCL_ERROR;
-            }
-        } else if (OPT_CMP(opt, "-maxworkers")) {
-            if (Tcl_GetIntFromObj(interp, objv[ii+1], &maxw) != TCL_OK) {
-                return TCL_ERROR;
-            }
-        } else if (OPT_CMP(opt, "-idletime")) {
-            if (Tcl_GetIntFromObj(interp, objv[ii+1], &idle) != TCL_OK) {
-                return TCL_ERROR;
-            }
-        } else if (OPT_CMP(opt, "-initcmd")) {
-            const char *val = Tcl_GetString(objv[ii+1]);
-            cmd  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
-        } else if (OPT_CMP(opt, "-exitcmd")) {
-            const char *val = Tcl_GetString(objv[ii+1]);
-            exs  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
-        } else {
-            goto usage;
-        }
+	char *opt = Tcl_GetString(objv[ii]);
+	if (OPT_CMP(opt, "-minworkers")) {
+	    if (Tcl_GetIntFromObj(interp, objv[ii+1], &minw) != TCL_OK) {
+		return TCL_ERROR;
+	    }
+	} else if (OPT_CMP(opt, "-maxworkers")) {
+	    if (Tcl_GetIntFromObj(interp, objv[ii+1], &maxw) != TCL_OK) {
+		return TCL_ERROR;
+	    }
+	} else if (OPT_CMP(opt, "-idletime")) {
+	    if (Tcl_GetIntFromObj(interp, objv[ii+1], &idle) != TCL_OK) {
+		return TCL_ERROR;
+	    }
+	} else if (OPT_CMP(opt, "-initcmd")) {
+	    const char *val = Tcl_GetString(objv[ii+1]);
+	    cmd  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
+	} else if (OPT_CMP(opt, "-exitcmd")) {
+	    const char *val = Tcl_GetString(objv[ii+1]);
+	    exs  = strcpy((char *)ckalloc(objv[ii+1]->length+1), val);
+	} else {
+	    goto usage;
+	}
     }
 
     /*
@@ -254,13 +254,13 @@ TpoolCreateObjCmd(
      */
 
     if (minw < 0) {
-        minw = 0;
+	minw = 0;
     }
     if (maxw < 0) {
-        maxw = TPOOL_MAXWORKERS;
+	maxw = TPOOL_MAXWORKERS;
     }
     if (minw > maxw) {
-        maxw = minw;
+	maxw = minw;
     }
 
     /*
@@ -289,13 +289,13 @@ TpoolCreateObjCmd(
 
     Tcl_MutexLock(&tpoolPtr->mutex);
     for (ii = 0; ii < tpoolPtr->minWorkers; ii++) {
-        if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
-            Tcl_MutexUnlock(&tpoolPtr->mutex);
-            Tcl_MutexLock(&listMutex);
-            TpoolRelease(tpoolPtr);
-            Tcl_MutexUnlock(&listMutex);
-            return TCL_ERROR;
-        }
+	if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
+	    Tcl_MutexUnlock(&tpoolPtr->mutex);
+	    Tcl_MutexLock(&listMutex);
+	    TpoolRelease(tpoolPtr);
+	    Tcl_MutexUnlock(&listMutex);
+	    return TCL_ERROR;
+	}
     }
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
@@ -306,9 +306,9 @@ TpoolCreateObjCmd(
 
  usage:
     Tcl_WrongNumArgs(interp, 1, objv,
-                     "?-minworkers count? ?-maxworkers count? "
-                     "?-initcmd script? ?-exitcmd script? "
-                     "?-idletime seconds?");
+		     "?-minworkers count? ?-maxworkers count? "
+		     "?-initcmd script? ?-exitcmd script? "
+		     "?-idletime seconds?");
     return TCL_ERROR;
 }
 
@@ -351,19 +351,19 @@ TpoolPostObjCmd(
      */
 
     if (objc < 3 || objc > 5) {
-        goto usage;
+	goto usage;
     }
     for (ii = 1; ii < objc; ii++) {
-        char *opt = Tcl_GetString(objv[ii]);
-        if (*opt != '-') {
-            break;
-        } else if (OPT_CMP(opt, "-detached")) {
-            detached  = 1;
-        } else if (OPT_CMP(opt, "-nowait")) {
-            nowait = 1;
-        } else {
-            goto usage;
-        }
+	char *opt = Tcl_GetString(objv[ii]);
+	if (*opt != '-') {
+	    break;
+	} else if (OPT_CMP(opt, "-detached")) {
+	    detached  = 1;
+	} else if (OPT_CMP(opt, "-nowait")) {
+	    nowait = 1;
+	} else {
+	    goto usage;
+	}
     }
 
     /*
@@ -371,7 +371,7 @@ TpoolPostObjCmd(
      */
     if (objc - ii != 2)
     {
-        goto usage;
+	goto usage;
     }
 
     tpoolName = Tcl_GetString(objv[ii]);
@@ -379,9 +379,9 @@ TpoolPostObjCmd(
     len = objv[ii+1]->length;
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     /*
@@ -396,62 +396,62 @@ TpoolPostObjCmd(
 
     Tcl_MutexLock(&tpoolPtr->mutex);
     if (nowait) {
-        if (tpoolPtr->numWorkers == 0) {
+	if (tpoolPtr->numWorkers == 0) {
 
-            /*
-             * Assure there is at least one worker running.
-             */
+	    /*
+	     * Assure there is at least one worker running.
+	     */
 
-            PushWaiter(tpoolPtr);
-            if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
-                Tcl_MutexUnlock(&tpoolPtr->mutex);
-                return TCL_ERROR;
-            }
+	    PushWaiter(tpoolPtr);
+	    if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
+		Tcl_MutexUnlock(&tpoolPtr->mutex);
+		return TCL_ERROR;
+	    }
 
-            /*
-             * Wait for worker to start while servicing the event loop
-             */
+	    /*
+	     * Wait for worker to start while servicing the event loop
+	     */
 
-            Tcl_MutexUnlock(&tpoolPtr->mutex);
-            tsdPtr->stop = -1;
-            while(tsdPtr->stop == -1) {
-                Tcl_DoOneEvent(TCL_ALL_EVENTS);
-            }
-            Tcl_MutexLock(&tpoolPtr->mutex);
-        }
+	    Tcl_MutexUnlock(&tpoolPtr->mutex);
+	    tsdPtr->stop = -1;
+	    while(tsdPtr->stop == -1) {
+		Tcl_DoOneEvent(TCL_ALL_EVENTS);
+	    }
+	    Tcl_MutexLock(&tpoolPtr->mutex);
+	}
     } else {
 
-        /*
-         * If there are no idle worker threads, start some new
-         * unless we are already running max number of workers.
-         * In that case wait for the next one to become idle.
-         */
+	/*
+	 * If there are no idle worker threads, start some new
+	 * unless we are already running max number of workers.
+	 * In that case wait for the next one to become idle.
+	 */
 
-        while (tpoolPtr->idleWorkers == 0) {
-            PushWaiter(tpoolPtr);
-            if (tpoolPtr->numWorkers < tpoolPtr->maxWorkers) {
+	while (tpoolPtr->idleWorkers == 0) {
+	    PushWaiter(tpoolPtr);
+	    if (tpoolPtr->numWorkers < tpoolPtr->maxWorkers) {
 
-                /*
-                 * No more free workers; start new one
-                 */
+		/*
+		 * No more free workers; start new one
+		 */
 
-                if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
-                    Tcl_MutexUnlock(&tpoolPtr->mutex);
-                    return TCL_ERROR;
-                }
-            }
+		if (CreateWorker(interp, tpoolPtr) != TCL_OK) {
+		    Tcl_MutexUnlock(&tpoolPtr->mutex);
+		    return TCL_ERROR;
+		}
+	    }
 
-            /*
-             * Wait for worker to start while servicing the event loop
-             */
+	    /*
+	     * Wait for worker to start while servicing the event loop
+	     */
 
-            Tcl_MutexUnlock(&tpoolPtr->mutex);
-            tsdPtr->stop = -1;
-            while(tsdPtr->stop == -1) {
-                Tcl_DoOneEvent(TCL_ALL_EVENTS);
-            }
-            Tcl_MutexLock(&tpoolPtr->mutex);
-        }
+	    Tcl_MutexUnlock(&tpoolPtr->mutex);
+	    tsdPtr->stop = -1;
+	    while(tsdPtr->stop == -1) {
+		Tcl_DoOneEvent(TCL_ALL_EVENTS);
+	    }
+	    Tcl_MutexLock(&tpoolPtr->mutex);
+	}
     }
 
     /*
@@ -462,8 +462,8 @@ TpoolPostObjCmd(
     memset(rPtr, 0, sizeof(TpoolResult));
 
     if (detached == 0) {
-        jobId = ++tpoolPtr->jobId;
-        rPtr->jobId = jobId;
+	jobId = ++tpoolPtr->jobId;
+	rPtr->jobId = jobId;
     }
 
     rPtr->script    = strcpy((char *)ckalloc(len+1), script);
@@ -476,7 +476,7 @@ TpoolPostObjCmd(
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
     if (detached == 0) {
-        Tcl_SetObjResult(interp, Tcl_NewWideIntObj(jobId));
+	Tcl_SetObjResult(interp, Tcl_NewWideIntObj(jobId));
     }
 
     return TCL_OK;
@@ -526,21 +526,21 @@ TpoolWaitObjCmd(
      */
 
     if (objc < 3 || objc > 4) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobIdList ?listVar");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobIdList ?listVar");
+	return TCL_ERROR;
     }
     if (objc == 4) {
-        listVar = objv[3];
+	listVar = objv[3];
     }
     if (Tcl_ListObjGetElements(interp, objv[2], &wObjc, &wObjv) != TCL_OK) {
-        return TCL_ERROR;
+	return TCL_ERROR;
     }
     tpoolName = Tcl_GetString(objv[1]);
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     InitWaiter();
@@ -549,52 +549,52 @@ TpoolWaitObjCmd(
 
     Tcl_MutexLock(&tpoolPtr->mutex);
     while (1) {
-        waitList = Tcl_NewListObj(0, NULL);
-        for (ii = 0; ii < wObjc; ii++) {
-            if (Tcl_GetWideIntFromObj(interp, wObjv[ii], &jobId) != TCL_OK) {
-                Tcl_MutexUnlock(&tpoolPtr->mutex);
-                return TCL_ERROR;
-            }
-            hPtr = Tcl_FindHashEntry(&tpoolPtr->jobsDone, (void *)(size_t)jobId);
-            if (hPtr) {
-                rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
-            } else {
-                rPtr = NULL;
-            }
-            if (rPtr == NULL) {
-                if (listVar) {
-                    Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
-                }
-            } else if (!rPtr->detached && rPtr->result) {
-                done++;
-                Tcl_ListObjAppendElement(interp, doneList, wObjv[ii]);
-            } else if (listVar) {
-                Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
-            }
-        }
-        if (done) {
-            break;
-        }
+	waitList = Tcl_NewListObj(0, NULL);
+	for (ii = 0; ii < wObjc; ii++) {
+	    if (Tcl_GetWideIntFromObj(interp, wObjv[ii], &jobId) != TCL_OK) {
+		Tcl_MutexUnlock(&tpoolPtr->mutex);
+		return TCL_ERROR;
+	    }
+	    hPtr = Tcl_FindHashEntry(&tpoolPtr->jobsDone, (void *)(size_t)jobId);
+	    if (hPtr) {
+		rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
+	    } else {
+		rPtr = NULL;
+	    }
+	    if (rPtr == NULL) {
+		if (listVar) {
+		    Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
+		}
+	    } else if (!rPtr->detached && rPtr->result) {
+		done++;
+		Tcl_ListObjAppendElement(interp, doneList, wObjv[ii]);
+	    } else if (listVar) {
+		Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
+	    }
+	}
+	if (done) {
+	    break;
+	}
 
-        /*
-         * None of the jobs done, wait for completion
-         * of the next job and try again.
-         */
+	/*
+	 * None of the jobs done, wait for completion
+	 * of the next job and try again.
+	 */
 
-        Tcl_DecrRefCount(waitList);
-        PushWaiter(tpoolPtr);
+	Tcl_DecrRefCount(waitList);
+	PushWaiter(tpoolPtr);
 
-        Tcl_MutexUnlock(&tpoolPtr->mutex);
-        tsdPtr->stop = -1;
-        while (tsdPtr->stop == -1) {
-            Tcl_DoOneEvent(TCL_ALL_EVENTS);
-        }
-        Tcl_MutexLock(&tpoolPtr->mutex);
+	Tcl_MutexUnlock(&tpoolPtr->mutex);
+	tsdPtr->stop = -1;
+	while (tsdPtr->stop == -1) {
+	    Tcl_DoOneEvent(TCL_ALL_EVENTS);
+	}
+	Tcl_MutexLock(&tpoolPtr->mutex);
     }
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
     if (listVar) {
-        Tcl_ObjSetVar2(interp, listVar, NULL, waitList, 0);
+	Tcl_ObjSetVar2(interp, listVar, NULL, waitList, 0);
     }
 
     Tcl_SetObjResult(interp, doneList);
@@ -639,21 +639,21 @@ TpoolCancelObjCmd(
      */
 
     if (objc < 3 || objc > 4) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobIdList ?listVar");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobIdList ?listVar");
+	return TCL_ERROR;
     }
     if (objc == 4) {
-        listVar = objv[3];
+	listVar = objv[3];
     }
     if (Tcl_ListObjGetElements(interp, objv[2], &wObjc, &wObjv) != TCL_OK) {
-        return TCL_ERROR;
+	return TCL_ERROR;
     }
     tpoolName = Tcl_GetString(objv[1]);
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     InitWaiter();
@@ -662,36 +662,38 @@ TpoolCancelObjCmd(
 
     Tcl_MutexLock(&tpoolPtr->mutex);
     for (ii = 0; ii < wObjc; ii++) {
-        if (Tcl_GetWideIntFromObj(interp, wObjv[ii], &jobId) != TCL_OK) {
-            return TCL_ERROR;
-        }
-        for (rPtr = tpoolPtr->workHead; rPtr; rPtr = rPtr->nextPtr) {
-            if (rPtr->jobId == jobId) {
-                if (rPtr->prevPtr != NULL) {
-                    rPtr->prevPtr->nextPtr = rPtr->nextPtr;
-                } else {
-                    tpoolPtr->workHead = rPtr->nextPtr;
-                }
-                if (rPtr->nextPtr != NULL) {
-                    rPtr->nextPtr->prevPtr = rPtr->prevPtr;
-                } else {
-                    tpoolPtr->workTail = rPtr->prevPtr;
-                }
-                SetResult(NULL, rPtr); /* Just to free the result */
-                ckfree(rPtr->script);
-                ckfree((char*)rPtr);
-                Tcl_ListObjAppendElement(interp, doneList, wObjv[ii]);
-                break;
-            }
-        }
-        if (rPtr == NULL && listVar) {
-            Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
-        }
+	if (Tcl_GetWideIntFromObj(interp, wObjv[ii], &jobId) != TCL_OK) {
+	    return TCL_ERROR;
+	}
+	for (rPtr = tpoolPtr->workHead; rPtr; rPtr = rPtr->nextPtr) {
+	    if (rPtr->jobId == jobId) {
+		if (rPtr->prevPtr != NULL) {
+		    rPtr->prevPtr->nextPtr = rPtr->nextPtr;
+		} else {
+		    tpoolPtr->workHead = rPtr->nextPtr;
+		}
+		if (rPtr->nextPtr != NULL) {
+		    rPtr->nextPtr->prevPtr = rPtr->prevPtr;
+		} else {
+		    tpoolPtr->workTail = rPtr->prevPtr;
+		}
+		SetResult(NULL, rPtr); /* Just to free the result */
+		if (rPtr->script) {
+		    ckfree(rPtr->script);
+		}
+		ckfree((char*)rPtr);
+		Tcl_ListObjAppendElement(interp, doneList, wObjv[ii]);
+		break;
+	    }
+	}
+	if (rPtr == NULL && listVar) {
+	    Tcl_ListObjAppendElement(interp, waitList, wObjv[ii]);
+	}
     }
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
     if (listVar) {
-        Tcl_ObjSetVar2(interp, listVar, NULL, waitList, 0);
+	Tcl_ObjSetVar2(interp, listVar, NULL, waitList, 0);
     }
 
     Tcl_SetObjResult(interp, doneList);
@@ -736,14 +738,14 @@ TpoolGetObjCmd(
      */
 
     if (objc < 3 || objc > 4) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobId ?result?");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId jobId ?result?");
+	return TCL_ERROR;
     }
     if (Tcl_GetWideIntFromObj(interp, objv[2], &jobId) != TCL_OK) {
-        return TCL_ERROR;
+	return TCL_ERROR;
     }
     if (objc == 4) {
-        resVar = objv[3];
+	resVar = objv[3];
     }
 
     /*
@@ -753,9 +755,9 @@ TpoolGetObjCmd(
     tpoolName = Tcl_GetString(objv[1]);
     tpoolPtr  = GetTpool(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     /*
@@ -767,15 +769,15 @@ TpoolGetObjCmd(
     Tcl_MutexLock(&tpoolPtr->mutex);
     hPtr = Tcl_FindHashEntry(&tpoolPtr->jobsDone, (void *)(size_t)jobId);
     if (hPtr == NULL) {
-        Tcl_MutexUnlock(&tpoolPtr->mutex);
-        Tcl_AppendResult(interp, "no such job", NULL);
-        return TCL_ERROR;
+	Tcl_MutexUnlock(&tpoolPtr->mutex);
+	Tcl_AppendResult(interp, "no such job", NULL);
+	return TCL_ERROR;
     }
     rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
     if (rPtr->result == NULL) {
-        Tcl_MutexUnlock(&tpoolPtr->mutex);
-        Tcl_AppendResult(interp, "job not completed", NULL);
-        return TCL_ERROR;
+	Tcl_MutexUnlock(&tpoolPtr->mutex);
+	Tcl_AppendResult(interp, "job not completed", NULL);
+	return TCL_ERROR;
     }
 
     Tcl_DeleteHashEntry(hPtr);
@@ -786,9 +788,9 @@ TpoolGetObjCmd(
     ckfree((char*)rPtr);
 
     if (resVar) {
-        Tcl_ObjSetVar2(interp, resVar, NULL, Tcl_GetObjResult(interp), 0);
-        Tcl_SetObjResult(interp, Tcl_NewIntObj(ret));
-        ret = TCL_OK;
+	Tcl_ObjSetVar2(interp, resVar, NULL, Tcl_GetObjResult(interp), 0);
+	Tcl_SetObjResult(interp, Tcl_NewIntObj(ret));
+	ret = TCL_OK;
     }
 
     return ret;
@@ -828,8 +830,8 @@ TpoolReserveObjCmd(
      */
 
     if (objc != 2) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
+	return TCL_ERROR;
     }
 
     tpoolName = Tcl_GetString(objv[1]);
@@ -837,10 +839,10 @@ TpoolReserveObjCmd(
     Tcl_MutexLock(&listMutex);
     tpoolPtr  = GetTpoolUnl(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_MutexUnlock(&listMutex);
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_MutexUnlock(&listMutex);
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     ret = TpoolReserve(tpoolPtr);
@@ -884,8 +886,8 @@ TpoolReleaseObjCmd(
      */
 
     if (objc != 2) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
+	return TCL_ERROR;
     }
 
     tpoolName = Tcl_GetString(objv[1]);
@@ -893,10 +895,10 @@ TpoolReleaseObjCmd(
     Tcl_MutexLock(&listMutex);
     tpoolPtr  = GetTpoolUnl(tpoolName);
     if (tpoolPtr == NULL) {
-        Tcl_MutexUnlock(&listMutex);
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_MutexUnlock(&listMutex);
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     ret = TpoolRelease(tpoolPtr);
@@ -939,17 +941,17 @@ TpoolSuspendObjCmd(
      */
 
     if (objc != 2) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
+	return TCL_ERROR;
     }
 
     tpoolName = Tcl_GetString(objv[1]);
     tpoolPtr  = GetTpool(tpoolName);
 
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     TpoolSuspend(tpoolPtr);
@@ -990,17 +992,17 @@ TpoolResumeObjCmd(
      */
 
     if (objc != 2) {
-        Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
-        return TCL_ERROR;
+	Tcl_WrongNumArgs(interp, 1, objv, "tpoolId");
+	return TCL_ERROR;
     }
 
     tpoolName = Tcl_GetString(objv[1]);
     tpoolPtr  = GetTpool(tpoolName);
 
     if (tpoolPtr == NULL) {
-        Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
-                         "\"", NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "can not find threadpool \"", tpoolName,
+			 "\"", NULL);
+	return TCL_ERROR;
     }
 
     TpoolResume(tpoolPtr);
@@ -1040,9 +1042,9 @@ TpoolNamesObjCmd(
 
     Tcl_MutexLock(&listMutex);
     for (tpoolPtr = tpoolList; tpoolPtr; tpoolPtr = tpoolPtr->nextPtr) {
-        char buf[32];
-        snprintf(buf, sizeof(buf), "%s%p", TPOOL_HNDLPREFIX, tpoolPtr);
-        Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(buf,-1));
+	char buf[32];
+	snprintf(buf, sizeof(buf), "%s%p", TPOOL_HNDLPREFIX, tpoolPtr);
+	Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(buf,-1));
     }
     Tcl_MutexUnlock(&listMutex);
     Tcl_SetObjResult(interp, listObj);
@@ -1091,13 +1093,13 @@ CreateWorker(
 
     Tcl_MutexLock(&startMutex);
     if (Tcl_CreateThread(&id, TpoolWorker, &result,
-                         TCL_THREAD_STACK_DEFAULT, 0) != TCL_OK) {
-        Tcl_SetObjResult(interp, Tcl_NewStringObj("can't create a new thread", -1));
-        Tcl_MutexUnlock(&startMutex);
-        return TCL_ERROR;
+			 TCL_THREAD_STACK_DEFAULT, 0) != TCL_OK) {
+	Tcl_SetObjResult(interp, Tcl_NewStringObj("can't create a new thread", -1));
+	Tcl_MutexUnlock(&startMutex);
+	return TCL_ERROR;
     }
     while(result.retcode == -1) {
-        Tcl_ConditionWait(&tpoolPtr->cond, &startMutex, NULL);
+	Tcl_ConditionWait(&tpoolPtr->cond, &startMutex, NULL);
     }
     Tcl_MutexUnlock(&startMutex);
 
@@ -1107,9 +1109,9 @@ CreateWorker(
      */
 
     if (result.retcode == 1) {
-        result.retcode = TCL_ERROR;
-        SetResult(interp, &result);
-        return TCL_ERROR;
+	result.retcode = TCL_ERROR;
+	SetResult(interp, &result);
+	return TCL_ERROR;
     }
 
     return TCL_OK;
@@ -1155,20 +1157,20 @@ TpoolWorker(
 #else
     interp = Tcl_CreateInterp();
     if (Tcl_Init(interp) != TCL_OK) {
-        rPtr->retcode = 1;
+	rPtr->retcode = 1;
     } else if (Thread_Init(interp) != TCL_OK) {
-        rPtr->retcode = 1;
+	rPtr->retcode = 1;
     } else {
-        rPtr->retcode = 0;
+	rPtr->retcode = 0;
     }
 #endif
 
     if (rPtr->retcode == 1) {
-        errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
-        rPtr->result = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
-        Tcl_ConditionNotify(&tpoolPtr->cond);
-        Tcl_MutexUnlock(&startMutex);
-        goto out;
+	errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
+	rPtr->result = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
+	Tcl_ConditionNotify(&tpoolPtr->cond);
+	Tcl_MutexUnlock(&startMutex);
+	goto out;
     }
 
     /*
@@ -1176,15 +1178,15 @@ TpoolWorker(
      */
 
     if (tpoolPtr->initScript) {
-        TpoolEval(interp, tpoolPtr->initScript, -1, rPtr);
-        if (rPtr->retcode != TCL_OK) {
-            rPtr->retcode = 1;
-            errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
-            rPtr->result  = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
-            Tcl_ConditionNotify(&tpoolPtr->cond);
-            Tcl_MutexUnlock(&startMutex);
-            goto out;
-        }
+	TpoolEval(interp, tpoolPtr->initScript, -1, rPtr);
+	if (rPtr->retcode != TCL_OK) {
+	    rPtr->retcode = 1;
+	    errMsg = Tcl_GetString(Tcl_GetObjResult(interp));
+	    rPtr->result  = strcpy((char *)ckalloc(strlen(errMsg)+1), errMsg);
+	    Tcl_ConditionNotify(&tpoolPtr->cond);
+	    Tcl_MutexUnlock(&startMutex);
+	    goto out;
+	}
     }
 
     /*
@@ -1192,11 +1194,11 @@ TpoolWorker(
      */
 
     if (tpoolPtr->idleTime == 0) {
-        idlePtr = NULL;
+	idlePtr = NULL;
     } else {
-        waitTime.sec  = tpoolPtr->idleTime;
-        waitTime.usec = 0;
-        idlePtr = &waitTime;
+	waitTime.sec  = tpoolPtr->idleTime;
+	waitTime.usec = 0;
+	idlePtr = &waitTime;
     }
 
     /*
@@ -1216,49 +1218,50 @@ TpoolWorker(
 
     Tcl_MutexLock(&tpoolPtr->mutex);
     while (!tpoolPtr->tearDown) {
-        SignalWaiter(tpoolPtr);
-        tpoolPtr->idleWorkers++;
-        rPtr = NULL;
-        tout = 0;
-        while (tpoolPtr->suspend
-               || (!tpoolPtr->tearDown && !tout
-                   && (rPtr = PopWork(tpoolPtr)) == NULL)) {
-            if (tpoolPtr->suspend && rPtr == NULL) {
-                Tcl_ConditionWait(&tpoolPtr->cond, &tpoolPtr->mutex, NULL);
-            } else if (rPtr == NULL) {
-                Tcl_Time t1, t2;
-                Tcl_GetTime(&t1);
-                Tcl_ConditionWait(&tpoolPtr->cond, &tpoolPtr->mutex, idlePtr);
-                Tcl_GetTime(&t2);
-                if (tpoolPtr->idleTime > 0) {
-                    tout = (t2.sec - t1.sec) >= tpoolPtr->idleTime;
-                }
-            }
-        }
-        tpoolPtr->idleWorkers--;
-        if (rPtr == NULL) {
-            if (tpoolPtr->numWorkers > tpoolPtr->minWorkers) {
-                break; /* Enough workers, can safely kill this one */
-            } else {
-                continue; /* Worker count at min, leave this one alive */
-            }
-        } else if (tpoolPtr->tearDown) {
-            PushWork(rPtr, tpoolPtr);
-            break; /* Kill worker because pool is going down */
-        }
-        Tcl_MutexUnlock(&tpoolPtr->mutex);
-        TpoolEval(interp, rPtr->script, rPtr->scriptLen, rPtr);
-        ckfree(rPtr->script);
-        Tcl_MutexLock(&tpoolPtr->mutex);
-        if (!rPtr->detached) {
-            int isNew;
-            Tcl_SetHashValue(Tcl_CreateHashEntry(&tpoolPtr->jobsDone,
-                                                 (void *)(size_t)rPtr->jobId, &isNew),
-                             rPtr);
-            SignalWaiter(tpoolPtr);
-        } else {
-            ckfree((char*)rPtr);
-        }
+	SignalWaiter(tpoolPtr);
+	tpoolPtr->idleWorkers++;
+	rPtr = NULL;
+	tout = 0;
+	while (tpoolPtr->suspend
+	       || (!tpoolPtr->tearDown && !tout
+		   && (rPtr = PopWork(tpoolPtr)) == NULL)) {
+	    if (tpoolPtr->suspend && rPtr == NULL) {
+		Tcl_ConditionWait(&tpoolPtr->cond, &tpoolPtr->mutex, NULL);
+	    } else if (rPtr == NULL) {
+		Tcl_Time t1, t2;
+		Tcl_GetTime(&t1);
+		Tcl_ConditionWait(&tpoolPtr->cond, &tpoolPtr->mutex, idlePtr);
+		Tcl_GetTime(&t2);
+		if (tpoolPtr->idleTime > 0) {
+		    tout = (t2.sec - t1.sec) >= tpoolPtr->idleTime;
+		}
+	    }
+	}
+	tpoolPtr->idleWorkers--;
+	if (rPtr == NULL) {
+	    if (tpoolPtr->numWorkers > tpoolPtr->minWorkers) {
+		break; /* Enough workers, can safely kill this one */
+	    } else {
+		continue; /* Worker count at min, leave this one alive */
+	    }
+	} else if (tpoolPtr->tearDown) {
+	    PushWork(rPtr, tpoolPtr);
+	    break; /* Kill worker because pool is going down */
+	}
+	Tcl_MutexUnlock(&tpoolPtr->mutex);
+	TpoolEval(interp, rPtr->script, rPtr->scriptLen, rPtr);
+	ckfree(rPtr->script);
+	rPtr->script = NULL;
+	Tcl_MutexLock(&tpoolPtr->mutex);
+	if (!rPtr->detached) {
+	    int isNew;
+	    Tcl_SetHashValue(Tcl_CreateHashEntry(&tpoolPtr->jobsDone,
+						 (void *)(size_t)rPtr->jobId, &isNew),
+			     rPtr);
+	    SignalWaiter(tpoolPtr);
+	} else {
+	    ckfree((char*)rPtr);
+	}
     }
 
     /*
@@ -1266,7 +1269,7 @@ TpoolWorker(
      */
 
     if (tpoolPtr->exitScript) {
-        TpoolEval(interp, tpoolPtr->exitScript, -1, NULL);
+	TpoolEval(interp, tpoolPtr->exitScript, -1, NULL);
     }
 
     tpoolPtr->numWorkers--;
@@ -1337,7 +1340,7 @@ PushWork(
 ) {
     SpliceIn(rPtr, tpoolPtr->workHead);
     if (tpoolPtr->workTail == NULL) {
-        tpoolPtr->workTail = rPtr;
+	tpoolPtr->workTail = rPtr;
     }
 }
 
@@ -1364,7 +1367,7 @@ PopWork(
     TpoolResult *rPtr = tpoolPtr->workTail;
 
     if (rPtr == NULL) {
-        return NULL;
+	return NULL;
     }
 
     tpoolPtr->workTail = rPtr->prevPtr;
@@ -1399,7 +1402,7 @@ PushWaiter(
 
     SpliceIn(tsdPtr->waitPtr, tpoolPtr->waitHead);
     if (tpoolPtr->waitTail == NULL) {
-        tpoolPtr->waitTail = tsdPtr->waitPtr;
+	tpoolPtr->waitTail = tsdPtr->waitPtr;
     }
 }
 
@@ -1426,7 +1429,7 @@ PopWaiter(
     TpoolWaiter *waitPtr =  tpoolPtr->waitTail;
 
     if (waitPtr == NULL) {
-        return NULL;
+	return NULL;
     }
 
     tpoolPtr->waitTail = waitPtr->prevPtr;
@@ -1492,12 +1495,12 @@ GetTpoolUnl (
     ThreadPool *tpoolPtr = NULL;
 
     if (sscanf(tpoolName, TPOOL_HNDLPREFIX"%p", &tpool) != 1) {
-        return NULL;
+	return NULL;
     }
     for (tpoolPtr = tpoolList; tpoolPtr; tpoolPtr = tpoolPtr->nextPtr) {
-        if (tpoolPtr == tpool) {
-            break;
-        }
+	if (tpoolPtr == tpool) {
+	    break;
+	}
     }
 
     return tpoolPtr;
@@ -1532,29 +1535,29 @@ TpoolEval(
 
     ret = Tcl_EvalEx(interp, script, scriptLen, TCL_EVAL_GLOBAL);
     if (rPtr == NULL || rPtr->detached) {
-        return ret;
+	return ret;
     }
     rPtr->retcode = ret;
     if (ret == TCL_ERROR) {
-        errorCode = Tcl_GetVar2(interp, "errorCode", NULL, TCL_GLOBAL_ONLY);
-        errorInfo = Tcl_GetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
-        if (errorCode != NULL) {
-            rPtr->errorCode = (char *)ckalloc(1 + strlen(errorCode));
-            strcpy(rPtr->errorCode, errorCode);
-        }
-        if (errorInfo != NULL) {
-            rPtr->errorInfo = (char *)ckalloc(1 + strlen(errorInfo));
-            strcpy(rPtr->errorInfo, errorInfo);
-        }
+	errorCode = Tcl_GetVar2(interp, "errorCode", NULL, TCL_GLOBAL_ONLY);
+	errorInfo = Tcl_GetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
+	if (errorCode != NULL) {
+	    rPtr->errorCode = (char *)ckalloc(1 + strlen(errorCode));
+	    strcpy(rPtr->errorCode, errorCode);
+	}
+	if (errorInfo != NULL) {
+	    rPtr->errorInfo = (char *)ckalloc(1 + strlen(errorInfo));
+	    strcpy(rPtr->errorInfo, errorInfo);
+	}
     }
 
     result = Tcl_GetString(Tcl_GetObjResult(interp));
     reslen = Tcl_GetObjResult(interp)->length;
 
     if (reslen == 0) {
-        rPtr->result = threadEmptyResult;
+	rPtr->result = threadEmptyResult;
     } else {
-        rPtr->result = strcpy((char *)ckalloc(1 + reslen), result);
+	rPtr->result = strcpy((char *)ckalloc(1 + reslen), result);
     }
 
     return ret;
@@ -1581,33 +1584,33 @@ SetResult(
     TpoolResult *rPtr
 ) {
     if (rPtr->retcode == TCL_ERROR) {
-        if (rPtr->errorCode) {
-            if (interp) {
-                Tcl_SetObjErrorCode(interp,Tcl_NewStringObj(rPtr->errorCode,-1));
-            }
-            ckfree(rPtr->errorCode);
-            rPtr->errorCode = NULL;
-        }
-        if (rPtr->errorInfo) {
-            if (interp) {
-                Tcl_AddErrorInfo(interp, rPtr->errorInfo);
-            }
-            ckfree(rPtr->errorInfo);
-            rPtr->errorInfo = NULL;
-        }
+	if (rPtr->errorCode) {
+	    if (interp) {
+		Tcl_SetObjErrorCode(interp,Tcl_NewStringObj(rPtr->errorCode,-1));
+	    }
+	    ckfree(rPtr->errorCode);
+	    rPtr->errorCode = NULL;
+	}
+	if (rPtr->errorInfo) {
+	    if (interp) {
+		Tcl_AddErrorInfo(interp, rPtr->errorInfo);
+	    }
+	    ckfree(rPtr->errorInfo);
+	    rPtr->errorInfo = NULL;
+	}
     }
     if (rPtr->result) {
-        if (rPtr->result == threadEmptyResult) {
-            if (interp) {
-                Tcl_ResetResult(interp);
-            }
-        } else {
-            if (interp) {
-                Tcl_SetObjResult(interp, Tcl_NewStringObj(rPtr->result,-1));
-            }
-            ckfree(rPtr->result);
-            rPtr->result = NULL;
-        }
+	if (rPtr->result == threadEmptyResult) {
+	    if (interp) {
+		Tcl_ResetResult(interp);
+	    }
+	} else {
+	    if (interp) {
+		Tcl_SetObjResult(interp, Tcl_NewStringObj(rPtr->result,-1));
+	    }
+	    ckfree(rPtr->result);
+	    rPtr->result = NULL;
+	}
     }
 }
 
@@ -1660,7 +1663,7 @@ TpoolRelease(
     Tcl_HashSearch search;
 
     if (tpoolPtr->refCount-- > 1) {
-        return tpoolPtr->refCount;
+	return tpoolPtr->refCount;
     }
 
     /*
@@ -1677,14 +1680,14 @@ TpoolRelease(
     Tcl_MutexLock(&tpoolPtr->mutex);
     tpoolPtr->tearDown = 1;
     while (tpoolPtr->numWorkers > 0) {
-        PushWaiter(tpoolPtr);
-        Tcl_ConditionNotify(&tpoolPtr->cond);
-        Tcl_MutexUnlock(&tpoolPtr->mutex);
-        tsdPtr->stop = -1;
-        while(tsdPtr->stop == -1) {
-            Tcl_DoOneEvent(TCL_ALL_EVENTS);
-        }
-        Tcl_MutexLock(&tpoolPtr->mutex);
+	PushWaiter(tpoolPtr);
+	Tcl_ConditionNotify(&tpoolPtr->cond);
+	Tcl_MutexUnlock(&tpoolPtr->mutex);
+	tsdPtr->stop = -1;
+	while(tsdPtr->stop == -1) {
+	    Tcl_DoOneEvent(TCL_ALL_EVENTS);
+	}
+	Tcl_MutexLock(&tpoolPtr->mutex);
     }
     Tcl_MutexUnlock(&tpoolPtr->mutex);
 
@@ -1693,10 +1696,10 @@ TpoolRelease(
      */
 
     if (tpoolPtr->initScript) {
-        ckfree(tpoolPtr->initScript);
+	ckfree(tpoolPtr->initScript);
     }
     if (tpoolPtr->exitScript) {
-        ckfree(tpoolPtr->exitScript);
+	ckfree(tpoolPtr->exitScript);
     }
 
     /*
@@ -1705,21 +1708,21 @@ TpoolRelease(
 
     hPtr = Tcl_FirstHashEntry(&tpoolPtr->jobsDone, &search);
     while (hPtr != NULL) {
-        rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
-        if (rPtr->result && rPtr->result != threadEmptyResult) {
-            ckfree(rPtr->result);
-        }
-        if (rPtr->retcode == TCL_ERROR) {
-            if (rPtr->errorInfo) {
-                ckfree(rPtr->errorInfo);
-            }
-            if (rPtr->errorCode) {
-                ckfree(rPtr->errorCode);
-            }
-        }
-        ckfree((char*)rPtr);
-        Tcl_DeleteHashEntry(hPtr);
-        hPtr = Tcl_NextHashEntry(&search);
+	rPtr = (TpoolResult*)Tcl_GetHashValue(hPtr);
+	if (rPtr->result && rPtr->result != threadEmptyResult) {
+	    ckfree(rPtr->result);
+	}
+	if (rPtr->retcode == TCL_ERROR) {
+	    if (rPtr->errorInfo) {
+		ckfree(rPtr->errorInfo);
+	    }
+	    if (rPtr->errorCode) {
+		ckfree(rPtr->errorCode);
+	    }
+	}
+	ckfree((char*)rPtr);
+	Tcl_DeleteHashEntry(hPtr);
+	hPtr = Tcl_NextHashEntry(&search);
     }
     Tcl_DeleteHashTable(&tpoolPtr->jobsDone);
 
@@ -1727,9 +1730,12 @@ TpoolRelease(
      * Cleanup jobs posted but never completed.
      */
 
-    for (rPtr = tpoolPtr->workHead; rPtr; rPtr = rPtr->nextPtr) {
-        ckfree(rPtr->script);
-        ckfree((char*)rPtr);
+    for (rPtr = tpoolPtr->workHead; rPtr; rPtr = tpoolPtr->workHead) {
+	tpoolPtr->workHead = rPtr->nextPtr;
+	if (rPtr->script) {
+	    ckfree(rPtr->script);
+	}
+	ckfree((char*)rPtr);
     }
     Tcl_MutexFinalize(&tpoolPtr->mutex);
     Tcl_ConditionFinalize(&tpoolPtr->cond);
@@ -1814,7 +1820,7 @@ SignalWaiter(
 
     waitPtr = PopWaiter(tpoolPtr);
     if (waitPtr == NULL) {
-        return;
+	return;
     }
 
     evPtr = (Tcl_Event*)ckalloc(sizeof(Tcl_Event));
@@ -1845,11 +1851,11 @@ InitWaiter ()
     ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
 
     if (tsdPtr->waitPtr == NULL) {
-        tsdPtr->waitPtr = (TpoolWaiter*)ckalloc(sizeof(TpoolWaiter));
-        tsdPtr->waitPtr->prevPtr  = NULL;
-        tsdPtr->waitPtr->nextPtr  = NULL;
-        tsdPtr->waitPtr->threadId = Tcl_GetCurrentThread();
-        Tcl_CreateThreadExitHandler(ThrExitHandler, tsdPtr);
+	tsdPtr->waitPtr = (TpoolWaiter*)ckalloc(sizeof(TpoolWaiter));
+	tsdPtr->waitPtr->prevPtr  = NULL;
+	tsdPtr->waitPtr->nextPtr  = NULL;
+	tsdPtr->waitPtr->threadId = Tcl_GetCurrentThread();
+	Tcl_CreateThreadExitHandler(ThrExitHandler, tsdPtr);
     }
 }
 
@@ -1904,7 +1910,7 @@ AppExitHandler(
      * Restart with head of list each time until empty. [Bug 1427570]
      */
     for (tpoolPtr = tpoolList; tpoolPtr; tpoolPtr = tpoolList) {
-        TpoolRelease(tpoolPtr);
+	TpoolRelease(tpoolPtr);
     }
     Tcl_MutexUnlock(&listMutex);
 }
@@ -1944,12 +1950,12 @@ TpoolInit (
     TCL_CMD(interp, TPOOL_CMD_PREFIX"resume",   TpoolResumeObjCmd);
 
     if (initialized == 0) {
-        Tcl_MutexLock(&listMutex);
-        if (initialized == 0) {
-            Tcl_CreateExitHandler(AppExitHandler, (ClientData)-1);
-            initialized = 1;
-        }
-        Tcl_MutexUnlock(&listMutex);
+	Tcl_MutexLock(&listMutex);
+	if (initialized == 0) {
+	    Tcl_CreateExitHandler(AppExitHandler, (ClientData)-1);
+	    initialized = 1;
+	}
+	Tcl_MutexUnlock(&listMutex);
     }
     return NULL;
 }
