@@ -46,8 +46,8 @@ puts stdout "Mainthread id is $::tcltest::mainThread"
 foreach file [lsort [::tcltest::getMatchingFiles]] {
     set tail [file tail $file]
     puts stdout $tail
-    if {[catch {source $file} msg]} {
-        puts stdout $msg
+    if {[catch {source -encoding utf-8 $file} msg]} {
+	puts stdout $msg
     }
 }
 
